/* -*- C++ -*- Time-stamp: <19 Nov 00 19:25:51 Michael Bischoff> */

/*****************************************************************************/
/*									     */
/*									     */
/*	QMatchIt version 1.0 -- file field.cpp				     */
/*									     */
/*	Implementation of the field base class of QMatchIt		     */
/*	written by Michael Bischoff (Michael.Bischoff@gmx.net)		     */
/*	November-2000							     */
/*	see COPYRIGHT.qmatchit for Copyright details			     */
/*									     */
/*									     */
/*****************************************************************************/

#include "field.h"
#include "fieldGraphics.h"

int field::currentFrame() {
    return baseFrame();
}

// just a function to hide the canvas from the game class

void field::advance_all() {
    QMatchItGraphics::getCanvas()->advance();
}


// create a new field object. the graphic sprite is also created

void field::init(int x, int y, int a_subtype) {
    subtype = a_subtype;
    idle_timer = 0;
    ctr = 0;
    state = state_normal;
    gr = new fieldGraphics(this, x, y);
}

// delete the field object

field::~field() {
    delete gr;
}

// define a new position: hands over to sprites class
void field::setXY(int x, int y) const {
    gr->setXY(x, y);
}

void field::startDestruction() {
    if (state == state_normal) {
	state = state_anim;
	gr->setAnimated(true);
    }
}

void field::stopDestruction() {
    state = state_normal;
    gr->setAnimated(false);
}

void field::setState(int a_state) {
    state = a_state;
    gr->setAnimated(state == state_anim ? true : isAnimated());
}
